Welcome to the KAT Communication Protocol's documentation!
==========================================================

Contents
========

.. toctree::
   :maxdepth: 2

   api
   kattypes
   sampling
   tutorial

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

